@@ -713,12 +713,15 @@ async def build_nodes_and_resolvers(
     update_forward_refs_inserts_str = "\n".join(
         [f"{o.node_name}Insert.update_forward_refs()" for o in object_types]
     )
+    update_forward_refs_patch_str = "\n".join(
+        [f"{o.node_name}Patch.update_forward_refs()" for o in object_types]
+    )
     update_forward_refs_nodes_str = "\n".join(
         [f"{o.node_name}.update_forward_refs()" for o in object_types]
     )
     nodes_str = "\n".join(node_strs)
     edge_resolver_map_str = "\n".join(edge_resolver_map_strs)
-    return f"{nodes_str}\n\n{update_forward_refs_inserts_str}\n\n{update_forward_refs_nodes_str}\n\n{edge_resolver_map_str}"
+    return f"{nodes_str}\n\n{update_forward_refs_inserts_str}\n\n{update_forward_refs_patch_str}\n\n{update_forward_refs_nodes_str}\n\n{edge_resolver_map_str}"
 
 
 def add_quotes_to_non_env_vars(s: str) -> str:
